<?php

/*
 *
 *  StatSig for Armagetron Advanced, by Dave Fancella
 *  
 *  @version $Id: aastats.inc.php,v 1.1.1.1 2005/02/19 01:27:59 dave Exp $
 *
 *  This file is part of StatSig.
 *   
 *  StatSig is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  StatSig is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with StatSig; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  StatSig is copyright 2005 by David Fancella
 *
 */

require_once("HttpClient.class.php");

class aaserver {
    var $servertype;
    var $serverlocation;
    var $servername;
    var $players = array();
    var $ladder = array();
    var $rounds = array();
    var $matches = array();
    var $hasplayers;
    var $usermessages = array('Nobody online.','One user online in spectator mode.');
    var $serverup = true;
    
    // @server : name of server
    // @location : path to armagetron's stats directory
    // @stype : 'aapassthrough' if it uses the php stat file passthrough script
    //          'local' if it doesn't use that script
    function aaserver($server, $location, $stype = 'local') {
        $this->servername = $server;
        $this->serverlocation = $location;
        $this->servertype = $stype;
        $this->hasplayers = false;
    }
    
    function GetPlayers() {
        return array_keys($this->players);
    }
    
    function AddPlayer($name, $ping, $score, $team) {
        $this->hasplayers = true;
        $this->players[$name]['ping'] = $ping;
        $this->players[$name]['score'] = $score;
        $this->players[$name]['team'] = $team;
    }
    
    function LoadStats() {
        switch($this->servertype) {
            case 'aapassthrough':
                $serverladder = $this->serverlocation . '?page=ladder';
                $serverplayers = $this->serverlocation . '?page=players';
                $servermatches = $this->serverlocation . '?page=matches';
                $serverrounds = $this->serverlocation . '?page=rounds';
                break;
            case 'local':
                $serverladder = $this->serverlocation . 'ladder.txt';
                $serverplayers = $this->serverlocation . 'players.txt';
                $servermatches = $this->serverlocation . 'won_matches.txt';
                $serverrounds = $this->serverlocation . 'won_rounds.txt';
                break;
            default:
                return;
        }
    
        $this->LoadLadder($serverladder);
        $this->LoadMatches($servermatches);
        $this->LoadPlayers($serverplayers);
        $this->LoadRounds($serverrounds);
    }
    
    function GetLadder() {
        return $this->ladder;
    }
    
    function GetFromCache($filename) {   
        $cachefile = "cache/" . urlencode($this->servername) . str_replace("/","-",$filename);
        $getremote = false;
        clearstatcache();
        if (file_exists($cachefile)) {
            echo $cachefile . "<br />";
            $Diff = (time() - filectime($cachefile))/60;
            if($Diff > 5) {
                $getremote = true;
            }
        } else {
            $getremote = true;
        }
        
        if ($getremote) {
            $contents = $this->load_file($filename);
        echo "<pre>"; var_dump($contents); echo "</pre>";
            if( $contents != false) {
                $handle = fopen($cachefile,'w');
                fwrite($handle, $contents);
                fclose($handle);
            } else {
                $contents = file_get_contents($cachefile);
            }
        } else {
            $contents = file_get_contents($cachefile);
        }
        
        return $contents;
    }
    
    function load_file($file) {
//        if( $this->serverup == true ) {
            echo $file;
            $serverinfo = parse_url($file);
            $query = explode($serverinfo['query'],'=');
            $stupid[$query[0]] = $query[1];
            $webclient = new HttpClient($serverinfo['host']);
            if (!$webclient->get($serverinfo['path'], $stupid)) {
                $this->serverup = false;
                die('An error occured: ' . $webclient->getError());
                //return false;
            }
            return $webclient->getContent();
//         } else {
//             return false;
//         }
    }
    
    
    function LoadLadder($ladderfile) {
        //$laddercontents = $this->GetFromCache($ladderfile);
        $laddercontents = file_get_contents($ladderfile);
        $ladder = explode("\n", $laddercontents);
        for ($i=0; $i < count($ladder); $i++) {
            $name = trim(strstr($ladder[$i], ' '));
            $score = substr($ladder[$i], 0, strpos($ladder[$i], ' '));
            $this->ladder[$name] = $score;
        }
    }

    function LoadPlayers($playerfile) {
        $playercontents = file_get_contents($playerfile);
        $players = explode("\n",$playercontents);
        if(!in_array(trim($players[0]),$this->usermessages)) {
            foreach($players as $row) {
                $player = substr($row,0,14);
                $player = trim($player);
                if($player != "Player:") {
                    $alive = trim(substr($row,14,7));
                    $points = trim(substr($row,21,7));
                    $ping = trim(substr($row,28,6));
                    $team = trim(substr($row,34));
                    $this->AddPlayer($player, $ping, $points, $team);
                }
            }
        }
    }
    
    function GetMatches() {
        return $this->matches;
    }
    
    function LoadMatches($matchfile) {
        //$matchcontents = $this->GetFromCache($matchfile);
        $matchcontents = file_get_contents($matchfile);
        $matches = explode("\n", $matchcontents);
        for ($i=0; $i < count($matches); $i++) {
            $name = trim(strstr($matches[$i], ' '));
            $score = substr($matches[$i], 0, strpos($matches[$i], ' '));
            $this->matches[$name] = $score;
        }
    }
    
    function GetRounds() {
        return $this->rounds;
    }
    
    function LoadRounds($roundfile) {
        //$roundcontents = $this->GetFromCache($roundfile);
        $roundcontents = file_get_contents($roundfile);
        $rounds = explode("\n", $roundcontents);
        for ($i=0; $i < count($rounds); $i++) {
            $name = trim(strstr($rounds[$i], ' '));
            $score = substr($rounds[$i], 0, strpos($rounds[$i], ' '));
            $this->rounds[$name] = $score;
        }
    }
}

class aastats {
    var $ladder = array();
    var $servers = array();
    var $players = array();
    var $matches = array();
    var $rounds = array();
    var $globalladder = array();
    var $globalmatches = array();
    var $globalrounds = array();
    var $serverlist = array();
    var $globalname = 'All Breakfast Servers';
    var $usermessages = array('Nobody online.','One user online in spectator mode.');
    
    function aastats() {
        $this->serverlist[] = $this->globalname;
    }
    
    function GetServerList() {
        return $this->serverlist;
    }
    
    function AddServer($server) {
        $this->servers[$server->servername] = $server;
        $this->serverlist[] = $server->servername;
    }
    
    function GetServer($server) {
        return $this->servers[$server];
    }
    
    function LoadGlobalServer() {
        // master foreach loop\
        foreach ($this->serverlist as $server) {
            if ($server != $this->globalname) {
                // Do the ladder first
                foreach($this->servers[$server]->GetLadder() as $name => $score) {
                    $this->globalladder[$name] += $score;
                }
                // Matches
                foreach($this->servers[$server]->GetMatches() as $name => $score) {
                    $this->globalmatches[$name] += $score;
                }
                // Rounds
                foreach($this->servers[$server]->GetRounds() as $name => $score) {
                    $this->globalrounds[$name] += $score;
                }
            }
        }
        arsort($this->globalladder);
        arsort($this->globalmatches);
        arsort($this->globalrounds);
    }
    
    function LoadServer($server) {
        $this->servers[$server]->LoadStats();
    }
    
    function GetPlayerLadder($server, $player) {
        if ($server == $this->globalname) {
            $searchladder = $this->globalladder;
        } else {
            $searchladder = $this->servers[$server]->GetLadder();
        }
        
        $searchind = 1;
        foreach($searchladder as $key=>$rung) {
            if( $key == $player ) {
                return array('player'=>$player,
                             'rank'=>$searchind,
                             'score'=>$rung);
            }
            $searchind++;
        }
        
        return array('player'=>$player,
                     'rank'=>'',
                     'score'=>'');
    }
    
    function GetLadder($server) {
        if ($server == $this->globalname) {
            return $this->globalladder;
        } else {
            return $this->servers[$server]->GetLadder();        
        }
    }

    function GetPlayerMatches($server, $player) {
        if ($server == $this->globalname) {
            $searchladder = $this->globalmatches;
        } else {
            $searchladder = $this->servers[$server]->GetMatches();
        }
        
        $searchind = 1;
        foreach($searchladder as $key=>$rung) {
            if( $key == $player ) {
                return array('player'=>$player,
                             'rank'=>$searchind,
                             'score'=>$rung);
            }
            $searchind++;
        }
        
        return array('player'=>$player,
                     'rank'=>'',
                     'score'=>'');
    }
    
    function GetMatches($server) {
        if ($server == $this->globalname) {
            return $this->globalmatches;
        } else {
            return $this->servers[$server]->GetMatches();
        }
    }
        
    function GetPlayerRounds($server, $player) {
        if ($server == $this->globalname) {
            $searchladder = $this->globalrounds;
        } else {
            $searchladder = $this->servers[$server]->GetRounds();
        }
        
        $searchind = 1;
        foreach($searchladder as $key=>$rung) {
            if( $key == $player ) {
                return array('player'=>$player,
                             'rank'=>$searchind,
                             'score'=>$rung);
            }
            $searchind++;
        }
        
        return array('player'=>$player,
                     'rank'=>'',
                     'score'=>'');
    }
    
    function GetRounds($server) {
        if ($server == $this->globalname) {
            return $this->globalrounds;
        } else {
            return $this->servers[$server]->GetRounds();
        }  
    }
    
}

?>


